@@ -7,6 +7,7 @@ import torch
 from einops import rearrange, repeat
 from pytorch_lightning import seed_everything
 
+import config
 from classy_imaginary.api import _prompts_to_embeddings, IMAGINAIRY_SAFETY_MODE
 from classy_imaginary import ImaginePrompt, ImagineResult
 from classy_imaginary.enhancers.clip_masking import get_img_mask
@@ -34,7 +35,7 @@ transformers_logging.set_verbosity_error()
 
 class Imagine:
     def __init__(self,
-                 model_name: str = "SD-1.5",
+                 model_name: str = config.DEFAULT_MODEL,
                  half_mode: bool = None,
                  precision="autocast",
                  for_inpainting: bool = False,
